@@ -44,13 +44,13 @@ Args:
   model_name: string, model name.
 """ + __tail_doc__ + """
 Model architectures:
-  | Model                           | Params | Image resolution | Top1 Acc |
-  | ------------------------------- | ------ | ---------------- | -------- |
-  | SwinTransformerV2Tiny_ns        | 28.3M  | 224              | 81.8     |
-  | SwinTransformerV2Small          | 49.7M  | 224              | 83.13    |
-  | SwinTransformerV2Base, 22k      | 87.9M  | 384              | 87.1     |
-  | SwinTransformerV2Large, 22k     | 196.7M | 384              | 87.7     |
-  | SwinTransformerV2Giant, 22k+ext | 2.60B  | 640              | 90.17    |
+  | Model                           | Params | FLOPs   | Input | Top1 Acc |
+  | ------------------------------- | ------ | ------- | ----- | -------- |
+  | SwinTransformerV2Tiny_ns        | 28.3M  | 4.69G   | 224   | 81.8     |
+  | SwinTransformerV2Small          | 49.7M  | 9.12G   | 224   | 83.13    |
+  | SwinTransformerV2Base, 22k      | 87.9M  | 50.89G  | 384   | 87.1     |
+  | SwinTransformerV2Large, 22k     | 196.7M | 109.40G | 384   | 87.7     |
+  | SwinTransformerV2Giant, 22k+ext | 2.60B  | 4.26T   | 640   | 90.17    |
 """
 
 SwinTransformerV2Tiny.__doc__ = __head_doc__ + """
